==> MITK-v2024.06.2-src.tar.gz: Modules/DICOM/files.cmake <==
file(GLOB_RECURSE H_FILES RELATIVE "${CMAKE_CURRENT_SOURCE_DIR}" "${CMAKE_CURRENT_SOURCE_DIR}/include/*")

set(CPP_FILES
  mitkBaseDICOMReaderService.cpp
  mitkDICOMFileReader.cpp
  mitkDICOMTagScanner.cpp
  mitkDICOMGDCMTagScanner.cpp
  mitkDICOMDCMTKTagScanner.cpp
  mitkDICOMImageBlockDescriptor.cpp
  mitkDICOMITKSeriesGDCMReader.cpp
  mitkDICOMDatasetSorter.cpp
  mitkDICOMTagBasedSorter.cpp
  mitkDICOMGDCMImageFrameInfo.cpp
  mitkDICOMImageFrameInfo.cpp
  mitkDICOMIOHelper.cpp
  mitkDICOMGenericImageFrameInfo.cpp
  mitkDICOMDatasetAccessingImageFrameInfo.cpp
  mitkDICOMSortCriterion.cpp
  mitkDICOMSortByTag.cpp
  mitkITKDICOMSeriesReaderHelper.cpp
  mitkEquiDistantBlocksSorter.cpp
  mitkNormalDirectionConsistencySorter.cpp
  mitkSortByImagePositionPatient.cpp
  mitkGantryTiltInformation.cpp
  mitkClassicDICOMSeriesReader.cpp
  mitkThreeDnTDICOMSeriesReader.cpp
  mitkDICOMTag.cpp
  mitkDICOMTagsOfInterestHelper.cpp
  mitkDICOMTagCache.cpp
  mitkDICOMGDCMTagCache.cpp
  mitkDICOMGenericTagCache.cpp
  mitkDICOMEnums.cpp
  mitkDICOMReaderConfigurator.cpp
  mitkDICOMFileReaderSelector.cpp
  mitkIDICOMTagsOfInterest.cpp
  mitkDICOMTagsOfInterestAddHelper.cpp
  mitkDICOMTagPath.cpp
  mitkDICOMProperty.cpp
  mitkDICOMFilesHelper.cpp
  mitkDICOMIOMetaInformationPropertyConstants.cpp
  legacy/mitkDicomSeriesReader.cpp
  legacy/mitkDicomSR_GantryTiltInformation.cpp
  legacy/mitkDicomSR_ImageBlockDescriptor.cpp
  legacy/mitkDicomSR_LoadDICOMRGBPixel.cpp
  legacy/mitkDicomSR_LoadDICOMRGBPixel4D.cpp
  legacy/mitkDicomSR_LoadDICOMScalar.cpp
  legacy/mitkDicomSR_LoadDICOMScalar4D.cpp
  legacy/mitkDicomSR_SliceGroupingResult.cpp
)

set(RESOURCE_FILES
  configurations/3D/classicreader.xml
  configurations/3D/imageposition.xml
  configurations/3D/imageposition_byacquisition.xml
  configurations/3D/instancenumber.xml
  configurations/3D/instancenumber_soft.xml
  configurations/3D/slicelocation.xml
  configurations/3D/simpleinstancenumber_soft.xml

  configurations/3DnT/classicreader.xml
  configurations/3DnT/imageposition.xml
  configurations/3DnT/imageposition_byacquisition.xml
  configurations/3DnT/imageposition_bytriggertime.xml
)

==> MITK-v2025.12-src.tar.gz: Modules/DICOM/files.cmake <==
file(GLOB_RECURSE H_FILES RELATIVE "${CMAKE_CURRENT_SOURCE_DIR}" "${CMAKE_CURRENT_SOURCE_DIR}/include/*")

set(CPP_FILES
  mitkBaseDICOMReaderService.cpp
  mitkDICOMFileReader.cpp
  mitkDICOMTagScanner.cpp
  mitkDICOMGDCMTagScanner.cpp
  mitkDICOMDCMTKTagScanner.cpp
  mitkDICOMImageBlockDescriptor.cpp
  mitkDICOMITKSeriesGDCMReader.cpp
  mitkDICOMDatasetSorter.cpp
  mitkDICOMTagBasedSorter.cpp
  mitkDICOMGDCMImageFrameInfo.cpp
  mitkDICOMImageFrameInfo.cpp
  mitkDICOMIOHelper.cpp
  mitkDICOMGenericImageFrameInfo.cpp
  mitkDICOMDatasetAccessingImageFrameInfo.cpp
  mitkDICOMSortCriterion.cpp
  mitkDICOMSortByTag.cpp
  mitkITKDICOMSeriesReaderHelper.cpp
  mitkEquiDistantBlocksSorter.cpp
  mitkNormalDirectionConsistencySorter.cpp
  mitkSortByImagePositionPatient.cpp
  mitkGantryTiltInformation.cpp
  mitkClassicDICOMSeriesReader.cpp
  mitkThreeDnTDICOMSeriesReader.cpp
  mitkDICOMCodeSequence.cpp
  mitkDICOMCodeSequenceWithModifiers.cpp
  mitkDICOMTag.cpp
  mitkDICOMTagsOfInterestHelper.cpp
  mitkDICOMTagCache.cpp
  mitkDICOMGDCMTagCache.cpp
  mitkDICOMGenericTagCache.cpp
  mitkDICOMEnums.cpp
  mitkDICOMReaderConfigurator.cpp
  mitkDICOMFileReaderSelector.cpp
  mitkIDICOMTagsOfInterest.cpp
  mitkDICOMTagsOfInterestAddHelper.cpp
  mitkDICOMTagPath.cpp
  mitkDICOMProperty.cpp
  mitkDICOMFilesHelper.cpp
  mitkDICOMIOMetaInformationPropertyConstants.cpp
  legacy/mitkDicomSeriesReader.cpp
  legacy/mitkDicomSR_GantryTiltInformation.cpp
  legacy/mitkDicomSR_ImageBlockDescriptor.cpp
  legacy/mitkDicomSR_LoadDICOMRGBPixel.cpp
  legacy/mitkDicomSR_LoadDICOMRGBPixel4D.cpp
  legacy/mitkDicomSR_LoadDICOMScalar.cpp
  legacy/mitkDicomSR_LoadDICOMScalar4D.cpp
  legacy/mitkDicomSR_SliceGroupingResult.cpp
)

set(RESOURCE_FILES
  configurations/3D/classicreader.xml
  configurations/3D/imageposition.xml
  configurations/3D/imageposition_byacquisition.xml
  configurations/3D/instancenumber.xml
  configurations/3D/instancenumber_soft.xml
  configurations/3D/slicelocation.xml
  configurations/3D/simpleinstancenumber_soft.xml

  configurations/3DnT/1_default_config.xml
  configurations/3DnT/classicreader.xml
  configurations/3DnT/imageposition.xml
  configurations/3DnT/imageposition_byacquisition.xml
  configurations/3DnT/imageposition_bytriggertime.xml
)
